PeatMapDisplay = {};

PeatMapDisplay.color_1 = {0.8706,0.4588,0.1804};
PeatMapDisplay.color_2 = {0.8941,0.5922,0.1098};
PeatMapDisplay.color_3 = {0.9216,0.7882,0.2510};
PeatMapDisplay.color_4 = {0.1804,0.7098,0.1647};
PeatMapDisplay.color_5 = {0.4157,0.7725,0.2078};
PeatMapDisplay.color_6 = {0.5804,0.8431,0.1647};

function PeatMapDisplay:loadMap(name)
	MapOverlayGenerator.buildSoilStateMapOverlay = PeatMapDisplay.buildNilStateMapOverlay;	

	MapOverlayGenerator.buildGrowthStateMapOverlay 	= PeatMapDisplay.buildGrowthStateMapOverlay;	
	MapOverlayGenerator.getDisplayGrowthStates 		= PeatMapDisplay.getDisplayGrowthStates;	
	MapOverlayGenerator.getDisplayCropTypes 		= PeatMapDisplay.getDisplayCropTypes;	
end

function PeatMapDisplay:deleteMap()
end

function PeatMapDisplay:draw(dt)
end;

function PeatMapDisplay:update(dt)
end;

function PeatMapDisplay:getDisplayCropTypes()
    local cropTypes = {}
    -- load crop type icon definitions in order of map configuration
    for i, fruitType in ipairs(self.missionFruitTypes) do
        if fruitType.shownOnMap and (fruitType.fruitTypeIndex == FruitType.PEAT or fruitType.fruitTypeIndex == FruitType.PEAT_TURNED) then
            local fillableIndex = self.fruitTypeManager:getFillTypeIndexByFruitTypeIndex(fruitType.fruitTypeIndex)
            local fillable = self.fillTypeManager:getFillTypeByIndex(fillableIndex)
            local iconFilename = fillable.hudOverlayFilenameSmall
            local iconUVs = Overlay.DEFAULT_UVS -- default crop type icons are separate files, use full texture
            local description = fillable.title
            table.insert(cropTypes, {
                colors = {[false] = fruitType.defaultColor, [true] = fruitType.colorBlindColor},
                iconFilename = iconFilename,
                iconUVs = iconUVs,
                description = description,
                fruitTypeIndex = fruitType.fruitTypeIndex,
                foliageId = fruitType.foliageId
            })
        end
    end
    return cropTypes
end

function PeatMapDisplay:buildGrowthStateMapOverlay(growthStateFilter, fruitTypeFilter)
	for _, displayCropType in ipairs(self.displayCropTypes) do
        if fruitTypeFilter[displayCropType.fruitTypeIndex] then
			if displayCropType.fruitTypeIndex == self.fruitTypeManager:getFruitTypeByName("PEAT").index then
				local foliageId = displayCropType.foliageId
			
				if growthStateFilter[MapOverlayGenerator.GROWTH_STATE_INDEX.CULTIVATED] then
					local color = PeatMapDisplay.color_1;
					setDensityMapVisualizationOverlayGrowthStateColor(self.foliageStateOverlay, foliageId, 1, color[1], color[2], color[3])
				end
				
				if growthStateFilter[MapOverlayGenerator.GROWTH_STATE_INDEX.GROWING] then 
					local color = PeatMapDisplay.color_2;
					setDensityMapVisualizationOverlayGrowthStateColor(self.foliageStateOverlay, foliageId, 2, color[1], color[2], color[3])
				end
				
				if growthStateFilter[MapOverlayGenerator.GROWTH_STATE_INDEX.HARVEST] then
					local color = PeatMapDisplay.color_3;
					setDensityMapVisualizationOverlayGrowthStateColor(self.foliageStateOverlay, foliageId, 3, color[1], color[2], color[3])
				end
				
			elseif displayCropType.fruitTypeIndex == self.fruitTypeManager:getFruitTypeByName("PEAT_TURNED").index then
				local desc = self.fruitTypeManager:getFruitTypeByName("PEAT_TURNED");
				local foliageId = displayCropType.foliageId
			
				if growthStateFilter[MapOverlayGenerator.GROWTH_STATE_INDEX.HARVESTED] then
					local color = PeatMapDisplay.color_4;
					setDensityMapVisualizationOverlayGrowthStateColor(self.foliageStateOverlay, foliageId, 1, color[1], color[2], color[3])
				end
				
				if growthStateFilter[MapOverlayGenerator.GROWTH_STATE_INDEX.PLOWED] then 
					local color = PeatMapDisplay.color_5;
					setDensityMapVisualizationOverlayGrowthStateColor(self.foliageStateOverlay, foliageId, 2, color[1], color[2], color[3])
				end
				
				if growthStateFilter[MapOverlayGenerator.GROWTH_STATE_INDEX.TOPPING] then
					local color = PeatMapDisplay.color_6;
					setDensityMapVisualizationOverlayGrowthStateColor(self.foliageStateOverlay, foliageId, 3, color[1], color[2], color[3])
				end
				
				if growthStateFilter[MapOverlayGenerator.GROWTH_STATE_INDEX.WITHERED] then
                    local color = self.displayGrowthStates[MapOverlayGenerator.GROWTH_STATE_INDEX.WITHERED].colors[self.isColorBlindMode][1]
                    setDensityMapVisualizationOverlayGrowthStateColor(self.foliageStateOverlay, foliageId, desc.cutState + 1, color[1], color[2], color[3])
				end
			end
        end
    end

    if g_currentMission.terrainDetailId ~= 0 then
        local fieldMask = bitShiftLeft(bitShiftLeft(1, g_currentMission.terrainDetailTypeNumChannels)-1, g_currentMission.terrainDetailTypeFirstChannel)
        if growthStateFilter[MapOverlayGenerator.GROWTH_STATE_INDEX.WITHERED] then
            local color = self.displayGrowthStates[MapOverlayGenerator.GROWTH_STATE_INDEX.WITHERED].colors[self.isColorBlindMode][1]
            setDensityMapVisualizationOverlayStateColor(self.foliageStateOverlay, g_currentMission.terrainDetailId, fieldMask, g_currentMission.terrainDetailTypeFirstChannel, g_currentMission.terrainDetailTypeNumChannels, g_currentMission.cultivatorValue, color[1], color[2], color[3])
        end
        --if growthStateFilter[MapOverlayGenerator.GROWTH_STATE_INDEX.PLOWED] then
        --    local color = self.displayGrowthStates[MapOverlayGenerator.GROWTH_STATE_INDEX.PLOWED].colors[self.isColorBlindMode][1]
        --    setDensityMapVisualizationOverlayStateColor(self.foliageStateOverlay, g_currentMission.terrainDetailId, fieldMask, g_currentMission.terrainDetailTypeFirstChannel, g_currentMission.terrainDetailTypeNumChannels, g_currentMission.plowValue, color[1], color[2], color[3])
        --end
    end
end

function PeatMapDisplay:getDisplayGrowthStates()
    return {
        -- indices are contiguous, so this definition is a valid array:
        [MapOverlayGenerator.GROWTH_STATE_INDEX.CULTIVATED] = {
            colors = {
                [true] = {PeatMapDisplay.color_1},
                [false] = {PeatMapDisplay.color_1}
            },
            description = g_i18n:getText("damp_state_1")
        },
        [MapOverlayGenerator.GROWTH_STATE_INDEX.GROWING] = {
            colors = {
                [true] = {PeatMapDisplay.color_2},
                [false] = {PeatMapDisplay.color_2}
            },
            description = g_i18n:getText("damp_state_2")
        },
        [MapOverlayGenerator.GROWTH_STATE_INDEX.HARVEST] = {
            colors = {
                [true] = {PeatMapDisplay.color_3},
                [false] = {PeatMapDisplay.color_3}
            },
            description = (g_i18n:getText("damp_state_3") .. " " .. g_i18n:getText("ready_to_turn"))
        },
        [MapOverlayGenerator.GROWTH_STATE_INDEX.HARVESTED] = {
            colors = {
                [true] = {PeatMapDisplay.color_4},
                [false] = {PeatMapDisplay.color_4}
            },
            description = g_i18n:getText("damp_state_4")
        },
        [MapOverlayGenerator.GROWTH_STATE_INDEX.PLOWED] = {
            colors = {
                [true] = {PeatMapDisplay.color_5},
                [false] = {PeatMapDisplay.color_5}
            },
            description = g_i18n:getText("damp_state_5")
        },
        [MapOverlayGenerator.GROWTH_STATE_INDEX.TOPPING] = {
            colors = {
                [true] = {PeatMapDisplay.color_6},
                [false] = {PeatMapDisplay.color_6}
            },
            description = (g_i18n:getText("damp_state_6") .. " " ..  g_i18n:getText("ready_to_pick"))
        },
        [MapOverlayGenerator.GROWTH_STATE_INDEX.WITHERED] = {
            colors = {
                [true] = {MapOverlayGenerator.FRUIT_COLOR_WITHERED[true]},
                [false] = {MapOverlayGenerator.FRUIT_COLOR_WITHERED[false]}
            },
            description = g_i18n:getText("peat_land")
        }
    }
end

function PeatMapDisplay:buildNilStateMapOverlay(soilStateFilter)
end

addModEventListener(PeatMapDisplay)
