peatCutter = {}

function peatCutter.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(SowingMachine, specializations);
end

function peatCutter.registerOverwrittenFunctions(vehicleType)
    SpecializationUtil.registerOverwrittenFunction(vehicleType, "processSowingMachineArea",    peatCutter.processSowingMachineArea)
    SowingMachine.onEndWorkAreaProcessing = peatCutter.onEndWorkAreaProcessing;

end

function peatCutter:processSowingMachineArea(superFunc, workArea, dt)
    local spec = self.spec_sowingMachine
    local changedArea, totalArea = 0, 0
    spec.isWorking = self:getLastSpeed() > 0.5
    if not spec.workAreaParameters.isActive then
        return changedArea, totalArea
    end

    if not spec.workAreaParameters.canFruitBePlanted then
        return changedArea, totalArea
    end
    local sx,_,sz = getWorldTranslation(workArea.start)
    local wx,_,wz = getWorldTranslation(workArea.width)
    local hx,_,hz = getWorldTranslation(workArea.height)
    spec.isProcessing = spec.isWorking

    local area, _ = FSDensityMapUtil.updateDirectSowingArea(spec.workAreaParameters.seedsFruitType, sx,sz, wx,wz, hx,hz, spec.workAreaParameters.angle, nil)
    changedArea = changedArea + area

    spec.workAreaParameters.lastChangedArea = spec.workAreaParameters.lastChangedArea + changedArea
    spec.workAreaParameters.lastStatsArea = spec.workAreaParameters.lastStatsArea + changedArea
    spec.workAreaParameters.lastTotalArea = spec.workAreaParameters.lastTotalArea + totalArea
    -- remove tireTracks
    FSDensityMapUtil.eraseTireTrack(sx,sz, wx,wz, hx,hz)
    self:updateMissionSowingWarning(sx, sz)
    return changedArea, totalArea
end

function peatCutter:onEndWorkAreaProcessing(dt, hasProcessed)
    local spec = self.spec_sowingMachine
    if self.isServer  then
        local stats = g_farmManager:getFarmById(self:getLastTouchedFarmlandFarmId()).stats
        if spec.workAreaParameters.lastChangedArea > 0 then
            local lastHa = MathUtil.areaToHa(spec.workAreaParameters.lastChangedArea, g_currentMission:getFruitPixelsToSqm())
            local ha = MathUtil.areaToHa(spec.workAreaParameters.lastStatsArea, g_currentMission:getFruitPixelsToSqm()) -- 4096px are mapped to 2048m
            stats:updateStats("sownHectares", ha)
            stats:updateStats("workedHectares", ha)
        end
        stats:updateStats("sownTime", dt/(1000*60))
        stats:updateStats("workedTime", dt/(1000*60))
    end
end



